==> realestate-supervise-common-1.1.0-20230317.090001-34-sources.jar: cn/gtmap/realestate/supervise/entity/BaSqrLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.bwmc;
import cn.gtmap.realestate.supervise.core.reflect.encrypt;
import cn.gtmap.realestate.supervise.core.reflect.id;
import cn.gtmap.realestate.supervise.core.reflect.ywh;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 申请人属性信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_sqr_ls"
)
public class BaSqrLs implements Serializable {


    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @ywh
    private String ywh;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @encrypt
    private String qlrmc;

    @XmlAttribute
    @Nullable
    private String qlrzjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String qlrzjh;

    @XmlAttribute
    @Nullable
    private String qlrtxdz;

    @XmlAttribute
    @Nullable
    private String qlryb;

    @XmlAttribute
    @Nullable
    private String qlrfrmc;

    @XmlAttribute
    @Nullable
    private String qlrfrdh;

    @XmlAttribute
    @Nullable
    private String qlrdlrmc;

    @XmlAttribute
    @Nullable
    private String qlrdlrdh;

    @XmlAttribute
    @Nullable
    private String qlrdljg;

    @XmlAttribute
    @Nullable
    @encrypt
    private String ywrmc;

    @XmlAttribute
    @Nullable
    private String ywrzjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String ywrzjh;

    @XmlAttribute
    @Nullable
    private String ywrtxdz;

    @XmlAttribute
    @Nullable
    private String ywryb;

    @XmlAttribute
    @Nullable
    private String ywrfrmc;

    @XmlAttribute
    @Nullable
    private String ywrfrdh;

    @XmlAttribute
    @Nullable
    private String ywrdlrmc;

    @XmlAttribute
    @Nullable
    private String ywrdlrdh;

    @XmlAttribute
    @Nullable
    private String ywrdljg;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @Nullable
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private Date sqsj;

    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYwh() {
        return ywh;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public String getQlrfrmc() {
        return qlrfrmc;
    }

    public String getQlrfrdh() {
        return qlrfrdh;
    }

    public String getQlrdlrmc() {
        return qlrdlrmc;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public String getQlrdljg() {
        return qlrdljg;
    }

    public String getYwrmc() {
        return ywrmc;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public String getYwrtxdz() {
        return ywrtxdz;
    }

    public String getYwryb() {
        return ywryb;
    }

    public String getYwrfrmc() {
        return ywrfrmc;
    }

    public String getYwrfrdh() {
        return ywrfrdh;
    }

    public String getYwrdlrmc() {
        return ywrdlrmc;
    }

    public String getYwrdlrdh() {
        return ywrdlrdh;
    }

    public String getYwrdljg() {
        return ywrdljg;
    }

    public String getBz() {
        return bz;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public void setQlrfrmc(String qlrfrmc) {
        this.qlrfrmc = qlrfrmc;
    }

    public void setQlrfrdh(String qlrfrdh) {
        this.qlrfrdh = qlrfrdh;
    }

    public void setQlrdlrmc(String qlrdlrmc) {
        this.qlrdlrmc = qlrdlrmc;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public void setYwrtxdz(String ywrtxdz) {
        this.ywrtxdz = ywrtxdz;
    }

    public void setYwryb(String ywryb) {
        this.ywryb = ywryb;
    }

    public void setYwrfrmc(String ywrfrmc) {
        this.ywrfrmc = ywrfrmc;
    }

    public void setYwrfrdh(String ywrfrdh) {
        this.ywrfrdh = ywrfrdh;
    }

    public void setYwrdlrmc(String ywrdlrmc) {
        this.ywrdlrmc = ywrdlrmc;
    }

    public void setYwrdlrdh(String ywrdlrdh) {
        this.ywrdlrdh = ywrdlrdh;
    }

    public void setYwrdljg(String ywrdljg) {
        this.ywrdljg = ywrdljg;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}

==> realestate-supervise-common-1.1.0-20251208.011103-73-sources.jar: cn/gtmap/realestate/supervise/entity/BaSqrLs.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 申请人属性信息
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_sqr_ls"
)
public class BaSqrLs implements Serializable {


    @XmlAttribute
    @Id
    @id
    private String id;

    @XmlAttribute
    @ywh
    private String ywh;


    @XmlAttribute
    private String ysdm;

    @XmlAttribute
    @encrypt
    private String qlrmc;

    @XmlAttribute
    @Nullable
    private String qlrzjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String qlrzjh;

    @XmlAttribute
    @Nullable
    private String qlrtxdz;

    @XmlAttribute
    @Nullable
    private String qlryb;

    @XmlAttribute
    @Nullable
    private String qlrfrmc;

    @XmlAttribute
    @Nullable
    private String qlrfrdh;

    @XmlAttribute
    @Nullable
    private String qlrdlrmc;

    @XmlAttribute
    @Nullable
    private String qlrdlrdh;

    @XmlAttribute
    @Nullable
    private String qlrdljg;

    @XmlAttribute
    @Nullable
    @encrypt
    private String ywrmc;

    @XmlAttribute
    @Nullable
    private String ywrzjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String ywrzjh;

    @XmlAttribute
    @Nullable
    private String ywrtxdz;

    @XmlAttribute
    @Nullable
    private String ywryb;

    @XmlAttribute
    @Nullable
    private String ywrfrmc;

    @XmlAttribute
    @Nullable
    private String ywrfrdh;

    @XmlAttribute
    @Nullable
    private String ywrdlrmc;

    @XmlAttribute
    @Nullable
    private String ywrdlrdh;

    @XmlAttribute
    @Nullable
    private String ywrdljg;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @Nullable
    private String qxdm;

    @Nullable
    private Date sjgxsj;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private Date sqsj;

    @sqlx
    private String sqlx;

    @bdcdyh
    private String bdcdyh;


    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public Date getSqsj() {
        return sqsj;
    }

    public void setSqsj(Date sqsj) {
        this.sqsj = sqsj;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getYwh() {
        return ywh;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public String getQlrzjzl() {
        return qlrzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public String getQlryb() {
        return qlryb;
    }

    public String getQlrfrmc() {
        return qlrfrmc;
    }

    public String getQlrfrdh() {
        return qlrfrdh;
    }

    public String getQlrdlrmc() {
        return qlrdlrmc;
    }

    public String getQlrdlrdh() {
        return qlrdlrdh;
    }

    public String getQlrdljg() {
        return qlrdljg;
    }

    public String getYwrmc() {
        return ywrmc;
    }

    public String getYwrzjzl() {
        return ywrzjzl;
    }

    public String getYwrzjh() {
        return ywrzjh;
    }

    public String getYwrtxdz() {
        return ywrtxdz;
    }

    public String getYwryb() {
        return ywryb;
    }

    public String getYwrfrmc() {
        return ywrfrmc;
    }

    public String getYwrfrdh() {
        return ywrfrdh;
    }

    public String getYwrdlrmc() {
        return ywrdlrmc;
    }

    public String getYwrdlrdh() {
        return ywrdlrdh;
    }

    public String getYwrdljg() {
        return ywrdljg;
    }

    public String getBz() {
        return bz;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public void setQlrzjzl(String qlrzjzl) {
        this.qlrzjzl = qlrzjzl;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public void setQlryb(String qlryb) {
        this.qlryb = qlryb;
    }

    public void setQlrfrmc(String qlrfrmc) {
        this.qlrfrmc = qlrfrmc;
    }

    public void setQlrfrdh(String qlrfrdh) {
        this.qlrfrdh = qlrfrdh;
    }

    public void setQlrdlrmc(String qlrdlrmc) {
        this.qlrdlrmc = qlrdlrmc;
    }

    public void setQlrdlrdh(String qlrdlrdh) {
        this.qlrdlrdh = qlrdlrdh;
    }

    public void setQlrdljg(String qlrdljg) {
        this.qlrdljg = qlrdljg;
    }

    public void setYwrmc(String ywrmc) {
        this.ywrmc = ywrmc;
    }

    public void setYwrzjzl(String ywrzjzl) {
        this.ywrzjzl = ywrzjzl;
    }

    public void setYwrzjh(String ywrzjh) {
        this.ywrzjh = ywrzjh;
    }

    public void setYwrtxdz(String ywrtxdz) {
        this.ywrtxdz = ywrtxdz;
    }

    public void setYwryb(String ywryb) {
        this.ywryb = ywryb;
    }

    public void setYwrfrmc(String ywrfrmc) {
        this.ywrfrmc = ywrfrmc;
    }

    public void setYwrfrdh(String ywrfrdh) {
        this.ywrfrdh = ywrfrdh;
    }

    public void setYwrdlrmc(String ywrdlrmc) {
        this.ywrdlrmc = ywrdlrmc;
    }

    public void setYwrdlrdh(String ywrdlrdh) {
        this.ywrdlrdh = ywrdlrdh;
    }

    public void setYwrdljg(String ywrdljg) {
        this.ywrdljg = ywrdljg;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }


    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }
}
